@@ -19,16 +19,16 @@
         color=g2_ink(d1, 1.0, 0.0, 0.0)
         call g2_pen(d1, color)
         write (6,*) color
-        call g2_draw_string(d1, 15.0, 75.0, 'TEST (Window)')
+        call g2_string(d1, 15.0, 75.0, 'TEST (Window)')
 
         color=g2_ink(d2, 0.0, 1.0, 0.0)
         call g2_pen(d2, color)
         write (6,*) color        
-        call g2_draw_string(d2, 15.0, 75.0, 'TEST (File)')
+        call g2_string(d2, 15.0, 75.0, 'TEST (File)')
 
         call g2_pen(d, 1.0)
         call g2_circle(d, 20.0, 20.0, 10.0)
-        call g2_draw_string(d, 20.0, 20.0, 'All devices!')
+        call g2_string(d, 20.0, 20.0, 'All devices!')
         call g2_flush(d)
 
         call g2_close(d2)
