@@ -16,9 +16,11 @@
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ******************************************************************************/
 /* This is g2_GIF.h */
+#ifndef _G2_GIF_H
+#define _G2_GIF_H
 
 #include <stdio.h>
 
 int  g2_open_GIF(const char *filename, int width, int height);
 
-
+#endif /* _G2_GIF_H */
