@@ -20,6 +20,7 @@
 #include <stdarg.h>
 #include <limits.h>
 #include <math.h>
+#include <string.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 
@@ -655,4 +656,39 @@ int g2_X11_draw_string(int pid, void *pdp, int x, int y, char *text)
 
 
 
+int g2_X11_image(int pid, int x, int y, int width, int height, int *pen_array)
+{
+    g2_X11_device *xout=&g2_X11_dev[pid];
+    XImage *image=NULL;
+    Screen *screen;
+    unsigned long *ink_array;
+    int i;
 
+    ink_array=malloc(sizeof(unsigned long)*width*height);
+    for(i=0;i<width*height;i++)
+	ink_array[i]=xout->inks[pen_array[i]];
+
+    screen=DefaultScreenOfDisplay(xout->display);
+    printf("BP1\n");
+    image=XCreateImage(xout->display,
+		       DefaultVisualOfScreen(screen),
+		       DefaultDepthOfScreen(screen),
+		       ZPixmap,
+		       0,			  /* offset */
+		       (char *)ink_array,
+		       width, height,
+		       sizeof(unsigned long)*8,		  /* bitmap pad */
+		       0);			  /* bytes per line */
+    printf("BP2\n");
+    /* XInitImage(image); problems with AIX ?!! */
+    printf("BP3 image=%p\n", (void*)image);
+    XPutImage(xout->display, xout->window, xout->gc,
+	      image,
+	      0, 0,
+	      x, y, width, height);
+    printf("BP4\n");
+	
+    XDestroyImage(image);
+    free(ink_array);
+    return 0;
+}
