@@ -15,8 +15,8 @@
 **  along with this program; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ******************************************************************************/
-#ifndef G2_X11_H
-#define G2_X11_H
+#ifndef _G2_X11_H
+#define _G2_X11_H
 
 int g2_open_X11(int width, int height);
 
@@ -26,7 +26,7 @@ int g2_open_X11X(int width, int height,
 		 char *icon_data,
 		 int icon_width, int icon_height);
 
-#endif /* G2_X11_H */
+#endif /* _G2_X11_H */
 
 
 
