@@ -15,10 +15,10 @@
 **  along with this program; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ******************************************************************************/
-#ifndef G2_H
-#define G2_H
+#ifndef _G2_H
+#define _G2_H
 
-#define G2_VERSION "0.23"
+#define G2_VERSION "0.40"
 
 #define G2LD g2_ld()
 
@@ -27,6 +27,10 @@ enum QPshape {
     QPcirc
 };
 
+/* compatibility with old versions */
+#define g2_draw_string(dev, x, y, text) g2_string((dev), (x), (y), (text))
+
+
 
 int  g2_open_vd(void);
 void g2_attach(int vd_dev, int dev);
@@ -84,11 +88,14 @@ void g2_arc(int dev,
 void g2_filled_arc(int dev, double x, double y,
 		   double r1, double r2,
 		   double a1, double a2);
-void g2_draw_string(int dev, double x, double y, char *text);
+void g2_string(int dev, double x, double y, char *text);
+void g2_image(int dev, double x, double y, int x_size, int y_size, int *pens);
 
 void g2_set_QP(int dev, double d, enum QPshape shape);
 void g2_plot_QP(int dev, double x, double y);
 
 
+/** Actualy private function, but... **/
+int g2_device_exist(int dix);
 
-#endif /* G2_H */
+#endif /* _G2_H */
