@@ -15,8 +15,8 @@
 **  along with this program; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ******************************************************************************/
-#ifndef G2_CONFIG_H
-#define G2_CONFIG_H
+#ifndef _G2_CONFIG_H
+#define _G2_CONFIG_H
 
 /*
  *
@@ -28,4 +28,4 @@
 #define WARNINGS
 
 
-#endif /* G2_CONFIG_H */
+#endif /* _G2_CONFIG_H */
