@@ -15,8 +15,8 @@
 **  along with this program; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ******************************************************************************/
-#ifndef G2_VIRTUAL_DEVICE_H
-#define G2_VIRTUAL_DEVICE_H
+#ifndef _G2_VIRTUAL_DEVICE_H
+#define _G2_VIRTUAL_DEVICE_H
 
 typedef struct _g2_virtual_device {
     int  N;		             /* number of attached devices */
@@ -28,4 +28,4 @@ g2_virtual_device *g2_create_virtual_device();
 void g2_destroy_virtual_device(g2_virtual_device *vd);
 int g2_is_attached(int vd, int dev);
 
-#endif /* G2_VIRTUAL_DEVICE_H */
+#endif /* _G2_VIRTUAL_DEVICE_H */
